==> tekton-model-triggers-v1alpha1-6.6.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerSpecFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface TriggerSpecFluent<A extends TriggerSpecFluent<A>> extends Fluent<A>{
  public A addToBindings(Integer index,TriggerSpecBinding item);
  public A setToBindings(Integer index,TriggerSpecBinding item);
  public A addToBindings(io.fabric8.tekton.triggers.v1alpha1.TriggerSpecBinding... items);
  public A addAllToBindings(Collection<TriggerSpecBinding> items);
  public A removeFromBindings(io.fabric8.tekton.triggers.v1alpha1.TriggerSpecBinding... items);
  public A removeAllFromBindings(Collection<TriggerSpecBinding> items);
  public A removeMatchingFromBindings(Predicate<TriggerSpecBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildBindings instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TriggerSpecBinding> getBindings();
  public List<TriggerSpecBinding> buildBindings();
  public TriggerSpecBinding buildBinding(Integer index);
  public TriggerSpecBinding buildFirstBinding();
  public TriggerSpecBinding buildLastBinding();
  public TriggerSpecBinding buildMatchingBinding(Predicate<TriggerSpecBindingBuilder> predicate);
  public Boolean hasMatchingBinding(Predicate<TriggerSpecBindingBuilder> predicate);
  public A withBindings(List<TriggerSpecBinding> bindings);
  public A withBindings(io.fabric8.tekton.triggers.v1alpha1.TriggerSpecBinding... bindings);
  public Boolean hasBindings();
  public A addNewBinding(String apiversion,String kind,String name,String ref,String value);
  public TriggerSpecFluent.BindingsNested<A> addNewBinding();
  public TriggerSpecFluent.BindingsNested<A> addNewBindingLike(TriggerSpecBinding item);
  public TriggerSpecFluent.BindingsNested<A> setNewBindingLike(Integer index,TriggerSpecBinding item);
  public TriggerSpecFluent.BindingsNested<A> editBinding(Integer index);
  public TriggerSpecFluent.BindingsNested<A> editFirstBinding();
  public TriggerSpecFluent.BindingsNested<A> editLastBinding();
  public TriggerSpecFluent.BindingsNested<A> editMatchingBinding(Predicate<TriggerSpecBindingBuilder> predicate);
  public A addToInterceptors(Integer index,TriggerInterceptor item);
  public A setToInterceptors(Integer index,TriggerInterceptor item);
  public A addToInterceptors(io.fabric8.tekton.triggers.v1alpha1.TriggerInterceptor... items);
  public A addAllToInterceptors(Collection<TriggerInterceptor> items);
  public A removeFromInterceptors(io.fabric8.tekton.triggers.v1alpha1.TriggerInterceptor... items);
  public A removeAllFromInterceptors(Collection<TriggerInterceptor> items);
  public A removeMatchingFromInterceptors(Predicate<TriggerInterceptorBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildInterceptors instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TriggerInterceptor> getInterceptors();
  public List<TriggerInterceptor> buildInterceptors();
  public TriggerInterceptor buildInterceptor(Integer index);
  public TriggerInterceptor buildFirstInterceptor();
  public TriggerInterceptor buildLastInterceptor();
  public TriggerInterceptor buildMatchingInterceptor(Predicate<TriggerInterceptorBuilder> predicate);
  public Boolean hasMatchingInterceptor(Predicate<TriggerInterceptorBuilder> predicate);
  public A withInterceptors(List<TriggerInterceptor> interceptors);
  public A withInterceptors(io.fabric8.tekton.triggers.v1alpha1.TriggerInterceptor... interceptors);
  public Boolean hasInterceptors();
  public TriggerSpecFluent.InterceptorsNested<A> addNewInterceptor();
  public TriggerSpecFluent.InterceptorsNested<A> addNewInterceptorLike(TriggerInterceptor item);
  public TriggerSpecFluent.InterceptorsNested<A> setNewInterceptorLike(Integer index,TriggerInterceptor item);
  public TriggerSpecFluent.InterceptorsNested<A> editInterceptor(Integer index);
  public TriggerSpecFluent.InterceptorsNested<A> editFirstInterceptor();
  public TriggerSpecFluent.InterceptorsNested<A> editLastInterceptor();
  public TriggerSpecFluent.InterceptorsNested<A> editMatchingInterceptor(Predicate<TriggerInterceptorBuilder> predicate);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getServiceAccountName();
  public A withServiceAccountName(String serviceAccountName);
  public Boolean hasServiceAccountName();
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerSpecTemplate getTemplate();
  public TriggerSpecTemplate buildTemplate();
  public A withTemplate(TriggerSpecTemplate template);
  public Boolean hasTemplate();
  public TriggerSpecFluent.TemplateNested<A> withNewTemplate();
  public TriggerSpecFluent.TemplateNested<A> withNewTemplateLike(TriggerSpecTemplate item);
  public TriggerSpecFluent.TemplateNested<A> editTemplate();
  public TriggerSpecFluent.TemplateNested<A> editOrNewTemplate();
  public TriggerSpecFluent.TemplateNested<A> editOrNewTemplateLike(TriggerSpecTemplate item);
  public interface BindingsNested<N> extends Nested<N>,TriggerSpecBindingFluent<TriggerSpecFluent.BindingsNested<N>>{
    public N and();
    public N endBinding();
    
  }
  public interface InterceptorsNested<N> extends Nested<N>,TriggerInterceptorFluent<TriggerSpecFluent.InterceptorsNested<N>>{
    public N and();
    public N endInterceptor();
    
  }
  public interface TemplateNested<N> extends Nested<N>,TriggerSpecTemplateFluent<TriggerSpecFluent.TemplateNested<N>>{
    public N and();
    public N endTemplate();
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerSpecFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;

 /**
  * Generated
  */
public interface TriggerSpecFluent<A extends TriggerSpecFluent<A>> extends Fluent<A>{
  public A addToBindings(int index,TriggerSpecBinding item);
  public A setToBindings(int index,TriggerSpecBinding item);
  public A addToBindings(io.fabric8.tekton.triggers.v1alpha1.TriggerSpecBinding... items);
  public A addAllToBindings(Collection<TriggerSpecBinding> items);
  public A removeFromBindings(io.fabric8.tekton.triggers.v1alpha1.TriggerSpecBinding... items);
  public A removeAllFromBindings(Collection<TriggerSpecBinding> items);
  public A removeMatchingFromBindings(Predicate<TriggerSpecBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildBindings instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TriggerSpecBinding> getBindings();
  public List<TriggerSpecBinding> buildBindings();
  public TriggerSpecBinding buildBinding(int index);
  public TriggerSpecBinding buildFirstBinding();
  public TriggerSpecBinding buildLastBinding();
  public TriggerSpecBinding buildMatchingBinding(Predicate<TriggerSpecBindingBuilder> predicate);
  public Boolean hasMatchingBinding(Predicate<TriggerSpecBindingBuilder> predicate);
  public A withBindings(List<TriggerSpecBinding> bindings);
  public A withBindings(io.fabric8.tekton.triggers.v1alpha1.TriggerSpecBinding... bindings);
  public Boolean hasBindings();
  public A addNewBinding(String apiversion,String kind,String name,String ref,String value);
  public TriggerSpecFluent.BindingsNested<A> addNewBinding();
  public TriggerSpecFluent.BindingsNested<A> addNewBindingLike(TriggerSpecBinding item);
  public TriggerSpecFluent.BindingsNested<A> setNewBindingLike(int index,TriggerSpecBinding item);
  public TriggerSpecFluent.BindingsNested<A> editBinding(int index);
  public TriggerSpecFluent.BindingsNested<A> editFirstBinding();
  public TriggerSpecFluent.BindingsNested<A> editLastBinding();
  public TriggerSpecFluent.BindingsNested<A> editMatchingBinding(Predicate<TriggerSpecBindingBuilder> predicate);
  public A addToInterceptors(int index,TriggerInterceptor item);
  public A setToInterceptors(int index,TriggerInterceptor item);
  public A addToInterceptors(io.fabric8.tekton.triggers.v1alpha1.TriggerInterceptor... items);
  public A addAllToInterceptors(Collection<TriggerInterceptor> items);
  public A removeFromInterceptors(io.fabric8.tekton.triggers.v1alpha1.TriggerInterceptor... items);
  public A removeAllFromInterceptors(Collection<TriggerInterceptor> items);
  public A removeMatchingFromInterceptors(Predicate<TriggerInterceptorBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildInterceptors instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TriggerInterceptor> getInterceptors();
  public List<TriggerInterceptor> buildInterceptors();
  public TriggerInterceptor buildInterceptor(int index);
  public TriggerInterceptor buildFirstInterceptor();
  public TriggerInterceptor buildLastInterceptor();
  public TriggerInterceptor buildMatchingInterceptor(Predicate<TriggerInterceptorBuilder> predicate);
  public Boolean hasMatchingInterceptor(Predicate<TriggerInterceptorBuilder> predicate);
  public A withInterceptors(List<TriggerInterceptor> interceptors);
  public A withInterceptors(io.fabric8.tekton.triggers.v1alpha1.TriggerInterceptor... interceptors);
  public Boolean hasInterceptors();
  public TriggerSpecFluent.InterceptorsNested<A> addNewInterceptor();
  public TriggerSpecFluent.InterceptorsNested<A> addNewInterceptorLike(TriggerInterceptor item);
  public TriggerSpecFluent.InterceptorsNested<A> setNewInterceptorLike(int index,TriggerInterceptor item);
  public TriggerSpecFluent.InterceptorsNested<A> editInterceptor(int index);
  public TriggerSpecFluent.InterceptorsNested<A> editFirstInterceptor();
  public TriggerSpecFluent.InterceptorsNested<A> editLastInterceptor();
  public TriggerSpecFluent.InterceptorsNested<A> editMatchingInterceptor(Predicate<TriggerInterceptorBuilder> predicate);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getServiceAccountName();
  public A withServiceAccountName(String serviceAccountName);
  public Boolean hasServiceAccountName();
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerSpecTemplate getTemplate();
  public TriggerSpecTemplate buildTemplate();
  public A withTemplate(TriggerSpecTemplate template);
  public Boolean hasTemplate();
  public TriggerSpecFluent.TemplateNested<A> withNewTemplate();
  public TriggerSpecFluent.TemplateNested<A> withNewTemplateLike(TriggerSpecTemplate item);
  public TriggerSpecFluent.TemplateNested<A> editTemplate();
  public TriggerSpecFluent.TemplateNested<A> editOrNewTemplate();
  public TriggerSpecFluent.TemplateNested<A> editOrNewTemplateLike(TriggerSpecTemplate item);
  public interface BindingsNested<N> extends Nested<N>,TriggerSpecBindingFluent<TriggerSpecFluent.BindingsNested<N>>{
    public N and();
    public N endBinding();
    
  }
  public interface InterceptorsNested<N> extends Nested<N>,TriggerInterceptorFluent<TriggerSpecFluent.InterceptorsNested<N>>{
    public N and();
    public N endInterceptor();
    
  }
  public interface TemplateNested<N> extends Nested<N>,TriggerSpecTemplateFluent<TriggerSpecFluent.TemplateNested<N>>{
    public N and();
    public N endTemplate();
    
  }
  
}
